Nion Swift
==========

Nion Swift: Scientific Image Processing
---------------------------------------
Nion Swift is open source scientific image processing software integrating hardware control, data acquisition,
visualization, processing, and analysis using Python. Nion Swift is easily extended using Python. It runs on Windows,
Linux, and macOS.

Nion Swift is developed for the operation of Nion electron microscope instruments. It is also useful as an offline tool
to visualize, process, and analyze data from the Nion instruments. It is being developed with the intention of
supporting additional instrumentation and fields.

.. start-badges

.. list-table::
    :stub-columns: 1

    * - tests
      - | |linux|
    * - package
      - |version|


.. |linux| image:: https://img.shields.io/travis/nion-software/nionswift/master.svg?label=Linux%20build
   :target: https://travis-ci.org/nion-software/nionswift
   :alt: Travis CI build status (Linux)

.. |version| image:: https://img.shields.io/pypi/v/nionswift.svg
   :target: https://pypi.org/project/nionswift/
   :alt: Latest PyPI version

.. end-badges

User's Guide
------------

- `Nion Swift User's Guide <http://nionswift.readthedocs.io/en/stable/index.html>`_

More Information
----------------

- `Changelog <https://github.com/nion-software/nionswift/blob/master/docs/release_notes.rst>`_
